<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:b1im="urn:com.sap.b1i.sim:b1imessage" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:js="com.sap.b1i.bpc_tools.Javascript" xmlns:rfc="urn:sap-com:document:sap:rfc:functions" xmlns:sim="urn:com.sap.b1i.sim:entity" xmlns:uplt="urn:com.sap.b1i.xcellerator:upltdoc" xmlns:utils2="com.sap.b1i.bpc_tools.Utilities" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" vpf:force="" jdbc:force="" rfc:force="" b1ie:force="" b1e:force="" xci:force="" sim:force="" utils2:force="" b1im:force="" uplt:force="" js:force="">
  <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="atom"/>
  <xsl:param name="sessionid"/>
  <xsl:variable name="msg" select="/vpf:Msg/vpf:Body/vpf:Payload[./@Role='S']"/>
  <xsl:variable name="vpSender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
  <xsl:variable name="vpObject" select="/vpf:Msg/vpf:Header/vpf:Sender/@ObjId"/>
  <xsl:variable name="vpReceiver" select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
  <xsl:variable name="vpCOBIAppVersion" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIAppVersion']/@value"/>
  <xsl:variable name="vpCOBIDeviceId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIDeviceId']/@value"/>
  <xsl:variable name="vpCOBIProfile" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIProfile']/@value"/>
  <xsl:variable name="vpCOBISysId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBISysId']/@value"/>
  <xsl:variable name="vpCOBIUserId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIUserId']/@value"/>
  <xsl:variable name="vpCOBIFiles" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIFiles']/@value"/>
  <xsl:variable name="vpCOBILogs" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBILogs']/@value"/>
  <xsl:variable name="vpCOBIEnablePDNDraft" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIEnablePDNDraft']/@value"/>
  <xsl:variable name="vpCOBIRemPrtPath" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIRemPrtPath']/@value"/>
  <xsl:template match="/">
    <xsl:variable name="vptsDoc" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
    <xsl:variable name="vpts" select="concat($vptsDoc/*/@year,'/',$vptsDoc/*/@month,'/',$vptsDoc/*/@date,' ',$vptsDoc/*/@hour,':',$vptsDoc/*/@minute,':',$vptsDoc/*/@second)"/>
    <Msg xmlns="urn:com.sap.b1i.vplatform:entity">
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <xsl:copy-of select="/vpf:Msg/vpf:Header"/>
      <Body>
        <xsl:copy-of select="/vpf:Msg/vpf:Body/*"/>
        <Payload Role="X" id="{$atom}">
          <xsl:call-template name="transform"/>
        </Payload>
      </Body>
    </Msg>
  </xsl:template>
  <xsl:key name="batches" match="//cobiwms/body/lines/line/batches/batch" use="concat(../../docLine, '_', batchNumber)"/>
  <xsl:template name="transform">
    <InventoryCounting>
      <DocumentEntry>
        <xsl:value-of select="$msg/cobiwms/body/document/docId"/>
      </DocumentEntry>
      <U_CWMS_Updater>
        <xsl:value-of select="$vpCOBIUserId"/>
      </U_CWMS_Updater>
      <U_CWMS_UpdaterDevice>
        <xsl:value-of select="$vpCOBIDeviceId"/>
      </U_CWMS_UpdaterDevice>
      <InventoryCountingLines>
        <xsl:for-each select="$msg/cobiwms/body/lines/line">
          <InventoryCountingLine>
            <LineNumber>
              <xsl:value-of select="docLine"/>
            </LineNumber>
            <ItemCode>
              <xsl:value-of select="itemCode"/>
            </ItemCode>
            <WarehouseCode>
              <xsl:value-of select="warehouseCode"/>
            </WarehouseCode>
            <BinEntry>
              <xsl:value-of select="locationId"/>
            </BinEntry>
            <Counted>
              <xsl:if test="isCounted = 'true'">tYES</xsl:if>
              <xsl:if test="isCounted = 'false'">tNO</xsl:if>
            </Counted>
            <xsl:if test="unitId = -1">
              <CountedQuantity>
                <xsl:value-of select="countedQuantity"/>
              </CountedQuantity>
              <UoMCode>
                <xsl:value-of select="unitCode"/>
              </UoMCode>
            </xsl:if>
            <xsl:if test="unitId != -1">
              <InventoryCountingLineUoMs>
                <InventoryCountingLineUoM>
                  <UoMCountedQuantity>
                    <xsl:value-of select="countedQuantity"/>
                  </UoMCountedQuantity>
                  <UoMCode>
                    <xsl:value-of select="unitCode"/>
                  </UoMCode>
                </InventoryCountingLineUoM>
              </InventoryCountingLineUoMs>
            </xsl:if>
            <xsl:if test="isClosed = 'true'">
              <LineStatus>clsClosed</LineStatus>
            </xsl:if>
            <xsl:if test="isClosed = 'false'">
              <InventoryCountingBatchNumbers>
                <xsl:for-each select="batches/batch[generate-id() = generate-id(key('batches', concat(../../docLine, '_', batchNumber))[1])]">
                  <InventoryCountingBatchNumber>
                    <BatchNumber>
                      <xsl:value-of select="batchNumber"/>
                    </BatchNumber>
                    <xsl:variable name="identicalBatches" select="../batch[batchNumber = current()/batchNumber]"/>
                    <Quantity>
                      <xsl:value-of select="sum($identicalBatches/countedQuantity)"/>
                    </Quantity>
                    <xsl:if test="$identicalBatches/productionDate">
                      <ManufactureDate>
                        <xsl:value-of select="$identicalBatches/productionDate[1]"/>
                      </ManufactureDate>
                    </xsl:if>
                    <xsl:if test="$identicalBatches/expiryDate">
                      <ExpiryDate>
                        <xsl:value-of select="$identicalBatches/expiryDate[1]"/>
                      </ExpiryDate>
                    </xsl:if>
                    <xsl:if test="attribute1">
                      <ManufacturerSerialNumber>
                        <xsl:value-of select="attribute1"/>
                      </ManufacturerSerialNumber>
                    </xsl:if>
                    <xsl:if test="attribute2">
                      <InternalSerialNumber>
                        <xsl:value-of select="attribute1"/>
                      </InternalSerialNumber>
                    </xsl:if>
                    <xsl:if test="details">
                      <Notes>
                        <xsl:value-of select="details"/>
                      </Notes>
                    </xsl:if>
                  </InventoryCountingBatchNumber>
                </xsl:for-each>
              </InventoryCountingBatchNumbers>
              <InventoryCountingSerialNumbers>
                <xsl:for-each select="serials/serial">
                  <InventoryCountingSerialNumber>
                    <InternalSerialNumber>
                      <xsl:value-of select="serialNumber"/>
                    </InternalSerialNumber>
                    <xsl:if test="systemNumber">
                      <SystemSerialNumber>
                        <xsl:value-of select="systemNumber"/>
                      </SystemSerialNumber>
                    </xsl:if>
                    <xsl:if test="lotNumber">
                      <LotNumber>
                        <xsl:value-of select="lotNumber"/>
                      </LotNumber>
                    </xsl:if>
                    <Quantity>1</Quantity>
                    <xsl:if test="manufacturerNumber">
                      <ManufacturerSerialNumber>
                        <xsl:value-of select="manufacturerNumber"/>
                      </ManufacturerSerialNumber>
                    </xsl:if>
                    <xsl:if test="details">
                      <Notes>
                        <xsl:value-of select="details"/>
                      </Notes>
                    </xsl:if>
                  </InventoryCountingSerialNumber>
                </xsl:for-each>
              </InventoryCountingSerialNumbers>
            </xsl:if>
          </InventoryCountingLine>
        </xsl:for-each>
      </InventoryCountingLines>
    </InventoryCounting>
  </xsl:template>
</xsl:stylesheet>
