<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:b1im="urn:com.sap.b1i.sim:b1imessage" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:js="com.sap.b1i.bpc_tools.Javascript" xmlns:rfc="urn:sap-com:document:sap:rfc:functions" xmlns:sim="urn:com.sap.b1i.sim:entity" xmlns:uplt="urn:com.sap.b1i.xcellerator:upltdoc" xmlns:utils2="com.sap.b1i.bpc_tools.Utilities" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" vpf:force="" jdbc:force="" rfc:force="" b1ie:force="" b1e:force="" xci:force="" sim:force="" utils2:force="" b1im:force="" uplt:force="" js:force="">
  <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="atom"/>
  <xsl:param name="sessionid"/>
  <xsl:variable name="msg" select="/vpf:Msg/vpf:Body/vpf:Payload[./@Role='S']"/>
  <xsl:variable name="vpSender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
  <xsl:variable name="vpObject" select="/vpf:Msg/vpf:Header/vpf:Sender/@ObjId"/>
  <xsl:variable name="vpReceiver" select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
  <xsl:variable name="vpCOBIAppVersion" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIAppVersion']/@value"/>
  <xsl:variable name="vpCOBIDeviceId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIDeviceId']/@value"/>
  <xsl:variable name="vpCOBIProfile" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIProfile']/@value"/>
  <xsl:variable name="vpCOBISysId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBISysId']/@value"/>
  <xsl:variable name="vpCOBIUserId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIUserId']/@value"/>
  <xsl:variable name="vpCOBIFiles" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIFiles']/@value"/>
  <xsl:variable name="vpCOBILogs" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBILogs']/@value"/>
  <xsl:variable name="vpCOBIEnablePDNDraft" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIEnablePDNDraft']/@value"/>
  <xsl:variable name="vpCOBIRemPrtPath" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIRemPrtPath']/@value"/>
  <xsl:template match="/">
    <xsl:variable name="vptsDoc" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
    <xsl:variable name="vpts" select="concat($vptsDoc/*/@year,'/',$vptsDoc/*/@month,'/',$vptsDoc/*/@date,' ',$vptsDoc/*/@hour,':',$vptsDoc/*/@minute,':',$vptsDoc/*/@second)"/>
    <Msg xmlns="urn:com.sap.b1i.vplatform:entity">
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <xsl:copy-of select="/vpf:Msg/vpf:Header"/>
      <Body>
        <xsl:copy-of select="/vpf:Msg/vpf:Body/*"/>
        <Payload Role="X" id="{$atom}">
          <xsl:call-template name="transform"/>
        </Payload>
      </Body>
    </Msg>
  </xsl:template>
  <xsl:template name="transform">
    <xsl:variable name="pkl" select="/vpf:Msg/vpf:Body/vpf:Payload[@id='atom5']/BOM/BO"/>
    <xsl:variable name="orderUpdateResults" select="/vpf:Msg/vpf:Body/vpf:Payload[@id='atom11']"/>
    <xsl:choose>
      <xsl:when test="//COBIError"/>
      <xsl:when test="$orderUpdateResults[@status != 'success'] or $orderUpdateResults[@DIresult != 'success']">
        <COBIError>
        </COBIError>
      </xsl:when>
      <xsl:when test="not($pkl)">
        <COBIError>
        </COBIError>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="lines" select="$msg/cobiwms/body/lines/line"/>
        <PickLists>
          <row>
            <U_CWMS_Updater>
              <xsl:value-of select="$vpCOBIUserId"/>
            </U_CWMS_Updater>
            <U_CWMS_UpdaterDevice>
              <xsl:value-of select="$vpCOBIDeviceId"/>
            </U_CWMS_UpdaterDevice>
          </row>
        </PickLists>
        <PickLists_Lines>
          <xsl:for-each select="$pkl/PickLists_Lines/row">
            <row>
              <xsl:copy-of select="LineNumber"/>
              <xsl:variable name="line" select="$lines[docLine = current()/LineNumber]"/>
              <xsl:if test="$line">
                <!-- FIXME: B1IF returns quantities in stock unit but expects them in the order line's unit??? -->
                <xsl:variable name="oldReleasedQty" select="ReleasedQuantity div $line/unitMultiplier"/>
                <xsl:variable name="oldPickedQty" select="PickedQuantity div $line/unitMultiplier"/>
                <xsl:variable name="totalQty" select="$oldReleasedQty + $oldPickedQty"/>
                <xsl:variable name="newPickedQty">
                  <xsl:if test="$vpCOBIProfile = 'CHEESE'">
                    <xsl:value-of select="$oldPickedQty + $line/pickedQuantity"/>
                  </xsl:if>
                  <xsl:if test="not($vpCOBIProfile = 'CHEESE')">
                    <xsl:value-of select="$line/pickedQuantity"/>
                  </xsl:if>
                </xsl:variable>
                <ReleasedQuantity>
                  <xsl:value-of select="$totalQty - $newPickedQty"/>
                </ReleasedQuantity>
                <PickedQuantity>
                  <xsl:value-of select="$newPickedQty"/>
                </PickedQuantity>
              </xsl:if>
            </row>
          </xsl:for-each>
        </PickLists_Lines>
        <BatchNumbers>
          <xsl:if test="$vpCOBIProfile = 'CHEESE'">
            <xsl:copy-of select="$pkl/BatchNumbers/row"/>
          </xsl:if>
          <xsl:for-each select="$lines/batches/batch[pickedQuantity &gt; 0]">
            <row>
              <BaseLineNumber>
                <xsl:value-of select="../../docLine"/>
              </BaseLineNumber>
              <BatchNumber>
                <xsl:value-of select="batchNumber"/>
              </BatchNumber>
              <Quantity>
                <xsl:value-of select="pickedQuantity"/>
              </Quantity>
            </row>
          </xsl:for-each>
        </BatchNumbers>
        <SerialNumbers>
          <xsl:if test="$vpCOBIProfile = 'CHEESE'">
            <xsl:copy-of select="$pkl/SerialNumbers/row"/>
          </xsl:if>
          <xsl:for-each select="$lines/serials/serial">
            <row>
              <BaseLineNumber>
                <xsl:value-of select="../../docLine"/>
              </BaseLineNumber>
              <InternalSerialNumber>
                <xsl:value-of select="serialNumber"/>
              </InternalSerialNumber>
              <Quantity>
                <xsl:if test="isPicked = 'false'">0</xsl:if>
                <xsl:if test="isPicked = 'true'">1</xsl:if>
              </Quantity>
              <xsl:if test="systemNumber">
                <SystemSerialNumber>
                  <xsl:value-of select="systemNumber"/>
                </SystemSerialNumber>
              </xsl:if>
            </row>
          </xsl:for-each>
        </SerialNumbers>
        <DocumentLinesBinAllocations>
          <xsl:for-each select="$lines">
            <xsl:variable name="docLine" select="docLine"/>
            <xsl:for-each select="locations/location[pickedQuantity &gt; 0]">
              <row>
                <BaseLineNumber>
                  <xsl:value-of select="$docLine"/>
                </BaseLineNumber>
                <SerialAndBatchNumbersBaseLine>
                            -1
                        </SerialAndBatchNumbersBaseLine>
                <BinAbsEntry>
                  <xsl:value-of select="id"/>
                </BinAbsEntry>
                <Quantity>
                  <xsl:value-of select="pickedQuantity"/>
                </Quantity>
              </row>
            </xsl:for-each>
            <xsl:for-each select="batches/batch">
              <xsl:variable name="position" select="position() - 1"/>
              <xsl:for-each select="locations/location">
                <row>
                  <BaseLineNumber>
                    <xsl:value-of select="$docLine"/>
                  </BaseLineNumber>
                  <SerialAndBatchNumbersBaseLine>
                    <xsl:value-of select="$position"/>
                  </SerialAndBatchNumbersBaseLine>
                  <BinAbsEntry>
                    <xsl:value-of select="id"/>
                  </BinAbsEntry>
                  <Quantity>
                    <xsl:value-of select="pickedQuantity"/>
                  </Quantity>
                </row>
              </xsl:for-each>
            </xsl:for-each>
            <xsl:for-each select="serials/serial">
              <xsl:variable name="position" select="position() - 1"/>
              <xsl:if test="location/id">
                <row>
                  <BaseLineNumber>
                    <xsl:value-of select="$docLine"/>
                  </BaseLineNumber>
                  <SerialAndBatchNumbersBaseLine>
                    <xsl:value-of select="$position"/>
                  </SerialAndBatchNumbersBaseLine>
                  <BinAbsEntry>
                    <xsl:value-of select="location/id"/>
                  </BinAbsEntry>
                  <Quantity>
                    <xsl:if test="isPicked = 'false'">0</xsl:if>
                    <xsl:if test="isPicked = 'true'">1</xsl:if>
                  </Quantity>
                </row>
              </xsl:if>
            </xsl:for-each>
          </xsl:for-each>
        </DocumentLinesBinAllocations>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
