<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:b1im="urn:com.sap.b1i.sim:b1imessage" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:js="com.sap.b1i.bpc_tools.Javascript" xmlns:rfc="urn:sap-com:document:sap:rfc:functions" xmlns:sim="urn:com.sap.b1i.sim:entity" xmlns:uplt="urn:com.sap.b1i.xcellerator:upltdoc" xmlns:utils2="com.sap.b1i.bpc_tools.Utilities" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" vpf:force="" jdbc:force="" rfc:force="" b1ie:force="" b1e:force="" xci:force="" sim:force="" utils2:force="" b1im:force="" uplt:force="" js:force="">
  <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="atom"/>
  <xsl:param name="sessionid"/>
  <xsl:variable name="msg" select="/vpf:Msg/vpf:Body/vpf:Payload[./@Role='S']"/>
  <xsl:variable name="vpSender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
  <xsl:variable name="vpObject" select="/vpf:Msg/vpf:Header/vpf:Sender/@ObjId"/>
  <xsl:variable name="vpReceiver" select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
  <xsl:variable name="vpCOBIAppVersion" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIAppVersion']/@value"/>
  <xsl:variable name="vpCOBIDeviceId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIDeviceId']/@value"/>
  <xsl:variable name="vpCOBIProfile" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIProfile']/@value"/>
  <xsl:variable name="vpCOBISysId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBISysId']/@value"/>
  <xsl:variable name="vpCOBIUserId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIUserId']/@value"/>
  <xsl:variable name="vpCOBIFiles" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIFiles']/@value"/>
  <xsl:variable name="vpCOBILogs" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBILogs']/@value"/>
  <xsl:variable name="vpCOBIEnablePDNDraft" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIEnablePDNDraft']/@value"/>
  <xsl:variable name="vpCOBIRemPrtPath" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIRemPrtPath']/@value"/>
  <xsl:template match="/">
    <xsl:variable name="vptsDoc" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
    <xsl:variable name="vpts" select="concat($vptsDoc/*/@year,'/',$vptsDoc/*/@month,'/',$vptsDoc/*/@date,' ',$vptsDoc/*/@hour,':',$vptsDoc/*/@minute,':',$vptsDoc/*/@second)"/>
    <vpf:Msg>
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <xsl:copy-of select="/vpf:Msg/vpf:Header"/>
      <vpf:Body>
        <xsl:copy-of select="/vpf:Msg/vpf:Body/*"/>
        <vpf:Payload Role="X" id="{$atom}" ts="{$vpts}">
          <xsl:call-template name="transform"/>
        </vpf:Payload>
      </vpf:Body>
    </vpf:Msg>
  </xsl:template>
  <xsl:template name="transform">
    <xsl:variable name="doc" select="$msg/cobiwms/body/document"/>
    <xsl:variable name="lines" select="$msg/cobiwms/body/lines/line"/>
    <xsl:for-each select="$lines[batches/batch and itemCode != '5019' and itemCode != '5020' and itemCode != '5021']">
      <ige>
        <sysId>
          <xsl:value-of select="$vpCOBISysId"/>
        </sysId>
        <BOM>
          <BO>
            <AdmInfo>
              <Object>60</Object>
              <Version>2</Version>
            </AdmInfo>
            <Documents>
              <row>
                <xsl:if test="$doc/date">
                  <DocDate>
                    <xsl:value-of select="$doc/date"/>
                  </DocDate>
                </xsl:if>
                <xsl:if test="$doc/employeeId != -1">
                  <DocumentsOwner>
                    <xsl:value-of select="$doc/employeeId"/>
                  </DocumentsOwner>
                </xsl:if>
                <Comments>
                  <xsl:text>Automatische Ausbuchung für Rezeptproduktion.</xsl:text>
                </Comments>
                <U_CWMS_Creator>
                  <xsl:value-of select="$doc/user"/>
                </U_CWMS_Creator>
                <U_CWMS_CreatorDevice>
                  <xsl:value-of select="$vpCOBIDeviceId"/>
                </U_CWMS_CreatorDevice>
              </row>
            </Documents>
            <Document_Lines>
              <row>
                <LineNum>0</LineNum>
                <ItemCode>
                  <xsl:value-of select="itemCode"/>
                </ItemCode>
                <Quantity>
                  <xsl:value-of select="quantity"/>
                </Quantity>
                <xsl:if test="unitId != -1">
                  <UseBaseUnits>N</UseBaseUnits>
                  <UoMEntry>
                    <xsl:value-of select="unitId"/>
                  </UoMEntry>
                </xsl:if>
              </row>
            </Document_Lines>
            <BatchNumbers>
              <xsl:for-each select="batches/batch">
                <row>
                  <BaseLineNumber>0</BaseLineNumber>
                  <BatchNumber>
                    <xsl:value-of select="batchNumber"/>
                  </BatchNumber>
                  <Quantity>
                    <xsl:value-of select="assignedQuantity"/>
                  </Quantity>
                </row>
              </xsl:for-each>
            </BatchNumbers>
          </BO>
        </BOM>
      </ige>
    </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>
